@@ -5,7 +5,7 @@
 
 use ratatui::{
     layout::{Alignment, Constraint, Direction, Layout, Rect},
-    style::{Color, Modifier, Style, Stylize},
+    style::{Color, Modifier, Style},
     text::{Line, Span},
     widgets::{Block, Borders, Cell, Clear, Paragraph, Row, Table, TableState, Wrap},
     Frame,
@@ -223,7 +223,7 @@ fn render_table(frame: &mut Frame, app: &App, area: Rect) {
                 .border_style(Style::default().fg(COLOR_BORDER))
                 .style(Style::default().bg(COLOR_BG)),
         )
-        .highlight_style(
+        .row_highlight_style(
             Style::default()
                 .bg(COLOR_SELECTED_BG)
                 .fg(COLOR_TEXT)
@@ -324,7 +324,30 @@ fn create_row(entry: &PortEntry, idx: usize, is_selected: bool) -> Row<'static>
 
 /// Render the command bar at the bottom
 fn render_command_bar(frame: &mut Frame, app: &App, area: Rect) {
-    let content = if app.filter_mode {
+    let content = if app.connect_mode {
+        // Connect input mode
+        if app.connect_key_mode {
+            Line::from(vec![
+                Span::styled("SSH Key: ", Style::default().fg(COLOR_ACCENT).bold()),
+                Span::styled(&app.connect_key_input, Style::default().fg(COLOR_TEXT)),
+                Span::styled("█", Style::default().fg(COLOR_ACCENT)), // Cursor
+                Span::styled(
+                    " (Enter to connect, Tab/Esc to skip)",
+                    Style::default().fg(COLOR_TEXT_DIM),
+                ),
+            ])
+        } else {
+            Line::from(vec![
+                Span::styled("Connect: ", Style::default().fg(COLOR_ACCENT).bold()),
+                Span::styled(&app.connect_input, Style::default().fg(COLOR_TEXT)),
+                Span::styled("█", Style::default().fg(COLOR_ACCENT)), // Cursor
+                Span::styled(
+                    " (Enter for SSH key, Tab to skip, Esc to cancel)",
+                    Style::default().fg(COLOR_TEXT_DIM),
+                ),
+            ])
+        }
+    } else if app.filter_mode {
         // Filter input mode (like vim command mode)
         Line::from(vec![
             Span::styled("/", Style::default().fg(COLOR_ACCENT).bold()),
@@ -348,6 +371,8 @@ fn render_command_bar(frame: &mut Frame, app: &App, area: Rect) {
                         Span::styled(" Column ", Style::default().fg(COLOR_TEXT_DIM)),
                         Span::styled("</>", Style::default().fg(COLOR_ACCENT)),
                         Span::styled(" Filter ", Style::default().fg(COLOR_TEXT_DIM)),
+                        Span::styled("<c>", Style::default().fg(COLOR_ACCENT)),
+                        Span::styled(" Connect ", Style::default().fg(COLOR_TEXT_DIM)),
                         Span::styled("<?>", Style::default().fg(COLOR_ACCENT)),
                         Span::styled(" Help", Style::default().fg(COLOR_TEXT_DIM)),
                     ])
@@ -426,6 +451,14 @@ fn render_help_popup(frame: &mut Frame) {
             Span::styled("    /        ", Style::default().fg(COLOR_WARNING)),
             Span::styled("Filter (supports regex)", Style::default().fg(COLOR_TEXT)),
         ]),
+        Line::from(vec![
+            Span::styled("    c        ", Style::default().fg(COLOR_WARNING)),
+            Span::styled("Connect to remote host", Style::default().fg(COLOR_TEXT)),
+        ]),
+        Line::from(vec![
+            Span::styled("    d        ", Style::default().fg(COLOR_WARNING)),
+            Span::styled("Disconnect from remote", Style::default().fg(COLOR_TEXT)),
+        ]),
         Line::from(vec![
             Span::styled("    Esc      ", Style::default().fg(COLOR_WARNING)),
             Span::styled("Clear filter / Close help", Style::default().fg(COLOR_TEXT)),
